Library for the EM-406 GPS module with time export support added

Fork of GPS by Simon Ford

Revision:
1:bc118a161471
Parent:
0:15611c7938a3
Child:
2:0d0ce3b0052d
diff -r 15611c7938a3 -r bc118a161471 GPS.h
--- a/GPS.h	Tue Jun 08 14:10:27 2010 +0000
+++ b/GPS.h	Wed Feb 21 21:05:14 2018 +0000
@@ -1,5 +1,6 @@
 /* mbed EM-406 GPS Module Library
  * Copyright (c) 2008-2010, sford
+ * Copyright (c) 2018 WilliamO7
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -45,6 +46,9 @@
     /** The latitude (call sample() to set) */
     float latitude;
     
+    /** The time in UTC float format (call sample() to set) */
+    float time_utc;
+    
 private:
     float trunc(float v);
     void getline();
@@ -1,5 +1,6 @@
-/* mbed EM-406 GPS Module Library
+/* mbed EM-406 GPS Module Library with time return support
  * Copyright (c) 2008-2010, sford